#
# spec file for package itinerary
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           itinerary
Version:        23.08.4
Release:        1.1
Summary:        Itinerary and boarding pass management application
License:        LGPL-2.0-or-later
URL:            https://apps.kde.org/itinerary
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  breeze5-icons
BuildRequires:  extra-cmake-modules
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5CalendarCore)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5FileMetaData)
BuildRequires:  cmake(KF5Holidays)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5KirigamiAddons)
BuildRequires:  cmake(KF5Mime)
BuildRequires:  cmake(KF5NetworkManagerQt)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5QQC2DeskopStyle)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5UnitConversion)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KOSMIndoorMap)
BuildRequires:  cmake(KPim5Itinerary)
BuildRequires:  cmake(KPim5PkPass)
BuildRequires:  cmake(KPublicTransport)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Location)
BuildRequires:  cmake(Qt5Positioning)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickCompiler)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} <= 1500
# variadic macro causes build issues
BuildRequires:  gcc10-c++
BuildRequires:  gcc10-PIE
%endif
# itinerary uses icons from the breeze theme
Requires:       breeze5-icons
# QML imports
Requires:       kirigami2
Requires:       prison-qt5-imports
Requires:       ki18n-imports
# Runtime dependencies (itinerary won't start without these packages)
Requires:       kopeninghours
Requires:       kosmindoormap
Requires:       kpublictransport


%description
Itinerary and boarding pass management application.

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?suse_version} <= 1500
  export CXX=g++-10
%endif

%cmake_kf5 -d build -- -DBUILD_TESTING=ON
%cmake_build

%install
%kf5_makeinstall -C build

# Should be Utility Maps, but the checker does not like it
%suse_update_desktop_file org.kde.itinerary Education Geography

%check
# one test fails on ppc64 (be). Upstream is investigating
%ifnarch ppc64
%ctest --exclude-regex "(itinerary-self-test)"
%endif

%find_lang %{name} --all-name

%files lang -f %{name}.lang

%files
%license LICENSES/*
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/kfilemetadata
%dir %{_kf5_plugindir}/kf5/thumbcreator
%dir %{_kf5_qmldir}/org
%dir %{_kf5_qmldir}/org/kde
%{_kf5_applicationsdir}/org.kde.itinerary.desktop
%{_kf5_appstreamdir}/org.kde.itinerary.appdata.xml
%{_kf5_bindir}/itinerary
%{_kf5_debugdir}/org_kde_itinerary.categories
%{_kf5_iconsdir}/hicolor/scalable/apps/org.kde.itinerary.svg
%{_kf5_libdir}/libSolidExtras.so
%{_kf5_notifydir}/itinerary.notifyrc
%{_kf5_plugindir}/kf5/kfilemetadata/kfilemetadata_itineraryextractor.so
%{_kf5_plugindir}/kf5/thumbcreator/itinerarythumbnail.so
%{_kf5_qmldir}/org/kde/solidextras/

%changelog
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Use ECM master version for Craft
  * Add job for submitting Qt 5 APKs to Google Play
  * Set bug address in KAboutData for the about dialog bug reporting action
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Add 23.08.3 release notes
  * Exclude Poppler's fallback fonts from the Itinerary APK
  * Use include:project for all templates
  * Use Kirigami Addons from the kf5 branch
  * Use merged Craft Android template
  * snapcraft: add file to reuse.
  * snapcraft: initial import snapcraft files.
  * Update Android asset exclusion list
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Add more sanity checks for transfers
  * More reasonable clang-tidy settings
  * Fix several word wrap issues for health certificate details
  * Ensure DB ticket reference is upper-cased
  * Disable Poppler Qt bindings
  * Fix Flatpak build after PIM switched master to Qt6
  * Use stable branch for Qt5 PIM libraries
  * Require POST_NOTIFICATION permission for Android SDK 33
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Add 23.08.1 release notes
  * Add release APK CI jobs
  * Fix editing bus and train elements without an associated ticket object (kde#474234)
  * Manually manage permissions in the Android manifest
  * Correctly size constrain Apple Wallet generic pass thumbnail image
  * Fix typos in the release notes
  * Fix progress computation on the initial journey stopover
  * Unbreak Flatpak build after the runtime removed ZXing
  * Add 23.08.0 release notes
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Add 23.08.0 release notes
  * Correctly clip weather forecasts at the end of the available data
  * Include icons needed by Kirigami Addons
  * Fix sunset/sunrise computation for weather icons
  * Remove health certificate Android shortcut
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Generalize the live data polling cooldown to all queries
  * Test pkpass update failure behind a captive portal
  * Don't poll pkpass updates in a continuous loop on errors
  * Don't check in PkPassManager whether a pass should be updated
  * Unify checks for updatable pkpasses
  * Check for live updatable pkpass files once they are actually added
  * Centralize QNetworkAccessManager creation
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes to list here.
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Add 23.04.3 release notes
  * Ensure we pass content: URLs fully encoded to Android API and QFile (kde#470643)
  * Add icon for boat/ferry reservations in the calendar
  * Explicitly specify supported types when importing from a calendar
  * Add map argument unit test for static elements at the begin/end
  * Fix infinite loop in computing static location map arguments
  * Fail less dramatically when ending up with an unknown pass
  * Work around the Android back key closing the app on secondary layers
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Add 23.04.2 release notes
  * Fix horizontal padding in editor page
  * Adapt test data to the changed name prefix cleaning in kitinerary
  * Don't attempt to select favorite locations based on invalid coordinates
  * Set better transfer delta times for restaurant reservations
  * Be more strict in discarding elements we cannot get live updates for
  * Properly check if the element a transfer is attached is a location change
  * Always pass passId to ActionsCard
  * Work around KUnitConversion deadlocking when needing a currency update (kde#469562)
  * Cache holiday region lookups
  * Fix attaching documents on multi-traveler reservations (kde#469347)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Consider transfers when determining the full trip group extend
  * Add 23.04.1 release notes
  * Validate imported passes and tickets
  * Fix imported PDFs losing their file name on Android
  * Improve Apple Wallet boarding pass layout for overflowing primary labels
  * Don't show the current element progress on canceled elements
  * Don't poll cancelled reservations for live updates
  * Ignore canceled reservations for transfers
  * Don't trigger connection warnings for canceled reservations
  * Make links in event descriptions clickable
* Mon Apr 24 2023 Christophe Marin <christophe@krop.fr>
- Add a breeze5-icons requirements. Itinerary requires this
  icon theme.
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Sun Jan 29 2023 Luca Beltrame <lbeltrame@kde.org>
- Add runtime requirement of ki18n-imports
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes to list here.
- Use GCC 10 for building kate on Leap 15.
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Format user visible numbers using the current locale
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Add 21.12.2 release notes
  * Add 21.12.1 release notes
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Don't break the timeline page when leaving development mode
  * Also make unit tests work against older KF versions without KI18nLocaleData
  * Fix station map platforms being mis-detected without live data
  * Get at least one live data update even for far future elements
  * Add 21.12.0 release notes
  * Fix ASAN unit test failure on the CI
  * Sanity-check model indexes
  * Fix certificate ordering when facing invalid dates
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Remove CI from stable branch again
  * Add CI for real
  * Enable new GitLab CI on stable branch.
  * Fix trend icon sizes on the statistics page
  * Also round the journey query delegate header background
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Also hide the issuer field when not present
  * Don't color health certificates without a verified signature green
  * NL CoronaCheck certificates specify no birth year, show that correctly
  * Handle fields not provided by the NL CoronaCheck certificates
  * Hide the health certificate swipe view when there are no certificates
  * Fix opening attached documents
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Add PDF417 barcode support for tickets (kde#444324)
  * Fix driving side warning for left-side driving countries (kde#440728)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * Include iso-codes data files needed by KF::I18n 5.88
  * [EventDelegate] Hide location name if there is none
  * [Delegates] Use preferredWidth instead of width
  * Prevent map panning in the location picker switching to the previous page
  * For departureCountry check departureLocation
  * Don't let checkbox labels force the minimum page width (kde#443200)
  * Add 21.08.2 changelog
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Too many changes since 21.08.1, only listing bugfixes:
  * Also word-wrap welcome page headers (kde#443200)
  * Fix timeline model test breaking during the last hour of the day (kde#442821)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Properly encode mail attachments received via FairEmail share intents
  * Rename icon according to Flatpak convention
  * Add breeze as fallback icon theme
  * Add 21.08.0 changelog
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Tue Aug  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add more runtime requirements.
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Too many changes to list here.
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes to list here.
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Hotfix for upcoming CardListView changes in Kirigami 5.84
  * Add content rating to appstream data
  * Fix line breaks in departure view disruption notes
  * Force using org.kde.desktop style on non-Android
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Fix application version display in tarball builds
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Exclude kde5_xml_mimetypes.qm from the APK
  * Wrap overly long event venue names
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Exclude a few more translation catalogs we don't need
  * Give the country combo box enough space
  * Complete the exclusion list for all iso-codes catalogs we don't need
  * Set the APK version based on what is defined in CMake
  * Extend the asset ignore pattern
  * Don't install files we don't need on Android
  * Refine the packaging exclusion list
  * Add APK exclusion lists for libraries and assets
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
- Drop upstream patch:
  * Update-weather-API-endpoint.patch
* Fri Mar  5 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patch:
  * Update-weather-API-endpoint.patch
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Properly handle journey section begins/ends when setting platform names
  * Make tests independent of locale configuration
  * Align transfer and journey query pages
  * Port timeline delegates away from QtQuick layouts
  * Explicitly anchor address label to the left
  * Fix opening the indoor map for elements that aren't location changes
* Thu Dec 10 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Add a category to the desktop file (kde#429114)
  * Fix build with older CMake versions
- Drop upstream patch:
  * 0001-Fix-build-with-older-CMake-versions.patch
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80.
  * New feature release
- itinerary is now released using the KDE release service.
- Add upstream patch:
  * 0001-Fix-build-with-older-CMake-versions.patch
* Tue Jul 23 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
